# src/word_hwp_converter/converter.py

import os
import win32com.client as win32
import pythoncom  # <--- 추가

def convert_hwp_to_pdf(input_path: str, output_path: str):
    """
    MS Word를 이용해 HWP 파일을 PDF로 변환합니다.
    이 함수를 실행하려면 PC에 MS Word가 설치되어 있어야 합니다.

    :param input_path: 변환할 HWP 파일의 절대 경로
    :param output_path: 저장할 PDF 파일의 절대 경로
    """
    pythoncom.CoInitialize()  # <--- 추가: COM 라이브러리 초기화
    word = None
    doc = None
    try:
        # 출력 폴더 생성
        output_dir = os.path.dirname(output_path)
        if not os.path.exists(output_dir):
            os.makedirs(output_dir)

        # Word 실행
        word = win32.gencache.EnsureDispatch('Word.Application')
        word.Visible = False

        # HWP 파일 열기
        doc = word.Documents.Open(input_path)

        # PDF로 저장
        wdFormatPDF = 17
        doc.SaveAs(output_path, FileFormat=wdFormatPDF)
        
    except Exception as e:
        raise e
    finally:
        # Word 종료
        if doc:
            doc.Close()
        if word:
            word.Quit()
        pythoncom.CoUninitialize()  # <--- 추가: COM 라이러리 해제